# Modeling SAP BTP
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/modeling-sap-btp#introduction)
  * [Gaining Insights from SAP BTP Modeling](https://help.sap.com/docs/leanix/ea/modeling-sap-btp#gaining-insights-from-sap-btp-modeling)
  * [Documenting SAP BTP Usage in the Application Landscape](https://help.sap.com/docs/leanix/ea/modeling-sap-btp#documenting-sap-btp-usage-in-the-application-landscape)
  * [Visualizing Tech Standards Usage and Governance Compliance](https://help.sap.com/docs/leanix/ea/modeling-sap-btp#visualizing-tech-standards-usage-and-governance-compliance)
  * [Building up SAP BTP as a Strategic Platform](https://help.sap.com/docs/leanix/ea/modeling-sap-btp#building-up-sap-btp-as-a-strategic-platform)
  * [Support Agile Development](https://help.sap.com/docs/leanix/ea/modeling-sap-btp#support-agile-development)
  * [General Guidelines and Best Practices for SAP BTP Modeling](https://help.sap.com/docs/leanix/ea/modeling-sap-btp#general-guidelines-and-best-practices-for-sap-btp-modeling)


Learn best practices for SAP BTP modeling, including guidelines for gaining insights and general approaches to structure your SAP BTP architecture.
